CMIP6DB module
==============

To activate **CMIP6DB** module use ``acccmip6 -o M``. This module allows all **Optinal arguments 1**. However, the input is always ``show``.

This module can be used to search all currently avalable models, experiemnts, variables, frequecies and realms in the CMIP6 database. 

**Usage:** without any arguments ::

        acccmip6 -o M

**output** ::

        <<You are using the CMIP6DB module now>>

        Use 'show' as the -m/-e/-f/-v/-r argument option instead of the names

        Example: acccmip -o M -m show >>> will generate a list of all currently available models in the CMIP6 database.

**Usage:** with argument ::

        acccmip6 -o M -m show

**output** ::

        <<You are using the CMIP6DB module now>>

        Use 'show' as the -m/-e/-f/-v/-r argument option instead of the names

        Example: acccmip -o M -m show >>> will generate a list of all currently available models in the CMIP6 database.

        Currently  49  models has outputs!

        Available models:


        ['AWI-CM-1-1-MR', 'BCC-CSM2-MR', 'BCC-ESM1', 'CAMS-CSM1-0', 'CESM2', 'CESM2-WACCM', 'CMCC-CM2-HR4', 'CMCC-CM2-VHR4', 'CNRM-CM6-1', 'CNRM-CM6-1-HR', 
        'CNRM-ESM2-1', 'CanESM5', 'E3SM-1-0', 'EC-Earth3', 'EC-Earth3-Veg', 'ECMWF-IFS-HR', 'ECMWF-IFS-LR', 'FGOALS-f3-L', 'FGOALS-g3', 'FIO-ESM-2-0', 
        'GFDL-AM4', 'GFDL-CM4', 'GFDL-CM4C192', 'GFDL-ESM4', 'GFDL-OM4p5B', 'GISS-E2-1-G', 'GISS-E2-1-G-CC', 'GISS-E2-1-H', 'HadGEM3-GC31-HM', 'HadGEM3-GC31-LL', 
        'HadGEM3-GC31-LM', 'HadGEM3-GC31-MM', 'IITM-ESM', 'IPSL-CM6A-ATM-HR', 'IPSL-CM6A-LR', 'MCM-UA-1-0', 'MIROC-ES2L', 'MIROC6', 'MPI-ESM1-2-HR', 
        'MRI-AGCM3-2-H', 'MRI-AGCM3-2-S', 'MRI-ESM2-0', 'NESM3', 'NICAM16-7S', 'NICAM16-8S', 'NICAM16-9S', 'NorESM2-LM', 'SAM0-UNICON', 'UKESM1-0-LL']
